<?php

// Credentials for accessing the MySQL database.
// You can modify these to suit your installation.
// Be sure to only change the text within the double quotes.
// The double quotes themselves should remain in place.

// Host: This is the server where the database runs.
$database_host = "localhost";
// Name: This is the name of the database.
$database_name = "bibledit-web";
// User: This is the username of the database administrator.
$database_user = "root";
// Pass: This is the password of the database administrator.
$database_pass = "root";

?>
